==> firefox-111.0.1.source.tar.xz: firefox-111.0.1/media/webrtc/signaling/gtest/MockCall.cpp <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "MockCall.h"

namespace test {

const webrtc::AudioSendStream::Config& MockAudioSendStream::GetConfig() const {
  return *mCallWrapper->GetMockCall()->mAudioSendConfig;
}

void MockAudioSendStream::Reconfigure(const Config& config) {
  mCallWrapper->GetMockCall()->mAudioSendConfig = mozilla::Some(config);
}

void MockAudioReceiveStream::SetDecoderMap(
    std::map<int, webrtc::SdpAudioFormat> decoder_map) {
  MOZ_ASSERT(mCallWrapper->GetMockCall()->mAudioReceiveConfig.isSome());
  mCallWrapper->GetMockCall()->mAudioReceiveConfig->decoder_map =
      std::move(decoder_map);
}

void MockAudioReceiveStream::SetRtpExtensions(
    std::vector<webrtc::RtpExtension> extensions) {
  MOZ_ASSERT(mCallWrapper->GetMockCall()->mAudioReceiveConfig.isSome());
  mCallWrapper->GetMockCall()->mAudioReceiveConfig->rtp.extensions =
      std::move(extensions);
}

const std::vector<webrtc::RtpExtension>&
MockAudioReceiveStream::GetRtpExtensions() const {
  static std::vector<webrtc::RtpExtension> rtpExtensions;
  return rtpExtensions;
}

webrtc::RtpHeaderExtensionMap MockAudioReceiveStream::GetRtpExtensionMap()
    const {
  return webrtc::RtpHeaderExtensionMap();
}

void MockVideoSendStream::ReconfigureVideoEncoder(
    webrtc::VideoEncoderConfig config) {
  mCallWrapper->GetMockCall()->mVideoSendEncoderConfig =
      mozilla::Some(config.Copy());
}

webrtc::RtpHeaderExtensionMap MockVideoReceiveStream::GetRtpExtensionMap()
    const {
  return webrtc::RtpHeaderExtensionMap();
}

}  // namespace test

==> firefox-142.0b6.source.tar.xz: firefox-142.0/media/webrtc/signaling/gtest/MockCall.cpp <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "MockCall.h"

namespace test {

const webrtc::AudioSendStream::Config& MockAudioSendStream::GetConfig() const {
  return *mCallWrapper->GetMockCall()->mAudioSendConfig;
}

void MockAudioSendStream::Reconfigure(const Config& config,
                                      webrtc::SetParametersCallback callback) {
  mCallWrapper->GetMockCall()->mAudioSendConfig = mozilla::Some(config);
}

void MockAudioReceiveStream::SetDecoderMap(
    std::map<int, webrtc::SdpAudioFormat> decoder_map) {
  MOZ_RELEASE_ASSERT(mCallWrapper->GetMockCall()->mAudioReceiveConfig.isSome());
  mCallWrapper->GetMockCall()->mAudioReceiveConfig->decoder_map =
      std::move(decoder_map);
}

void MockVideoSendStream::ReconfigureVideoEncoder(
    webrtc::VideoEncoderConfig config) {
  mCallWrapper->GetMockCall()->mVideoSendEncoderConfig =
      mozilla::Some(config.Copy());
}

void MockVideoSendStream::ReconfigureVideoEncoder(
    webrtc::VideoEncoderConfig config, webrtc::SetParametersCallback callback) {
  ReconfigureVideoEncoder(std::move(config));
}

void MockVideoSendStream::SetSource(
    rtc::VideoSourceInterface<webrtc::VideoFrame>* source,
    const webrtc::DegradationPreference& degradation_preference) {
  mCallWrapper->GetMockCall()->mConfiguredDegradationPreference =
      degradation_preference;
}

}  // namespace test
